sphinx.ext.todo – Support for todo items — flask-peewee v0.1.0 documentation

### Navigation

- index
- modules |
- flask-peewee v0.1.0 documentation »

# `sphinx.ext.todo` – Support for todo items

New in version 0.5.

There are two additional directives when using this extension:

`.. todo::`

  Use this directive like, for example, `note`.

  It will only show up in the output if :confval:`todo_include_todos` is true.

`.. todolist::`

  This directive is replaced by a list of all todo directives in the whole documentation, if :confval:`todo_include_todos` is true.

There is also an additional config value:

### Navigation

- index
- modules |
- flask-peewee v0.1.0 documentation »